package edu.kit.ipd.descartes.adaptation.model.dmm.util;

import org.eclipse.emf.common.util.EList;
import org.eclipse.emf.ecore.util.EcoreUtil;

import edu.kit.ipd.descartes.mm.adaptation.WeightedMetric;
import edu.kit.ipd.descartes.mm.adaptation.WeightingFunction;
import edu.kit.ipd.descartes.perfdatarepo.MetricType;
import edu.kit.ipd.descartes.perfdatarepo.MetricValue;
import edu.kit.ipd.descartes.perfdatarepo.Result;

public class WeightingFunctionHelper {

    /**
     * 
     * @param function
     * @param metricType
     * @return 
     *  Returns the weight of the {@code meticType} of the given {@code function}.<br>
     *  Returns {@code Double.NaN} if the {@code metricType} was not found.
     */
	public static double getWeightForMetricType(WeightingFunction function, MetricType metricType) {
		EList<WeightedMetric> weightedMetrics = function.getWeightedMetrics();

		for (WeightedMetric weightedMetric : weightedMetrics) {
			if (EcoreUtil.equals(weightedMetric.getMetricType(), metricType))
				return weightedMetric.getWeight();
		}

		return Double.NaN;
	}

	/**
	 * Searches the {@link MetricValue} of the given {@link MetricType} in the
	 * {@link Result} <code>resultBefore</code>
	 * 
	 * @param metricType The type of the metric to find
	 * @param resultBefore The result to search
	 * @return
	 */
	public static double getValueForMetricType(MetricType metricType, Result resultBefore) {
		EList<MetricValue> metricValues = resultBefore.getMetricValues();

		for (MetricValue metricValue : metricValues) {
			if (metricValue.getMetricType().equals(metricType))
				return metricValue.getValue();
		}
		return Double.NaN;
	}

}
