package edu.kit.ipd.descartes.adaptation.model.perfdatarepo;

import org.eclipse.emf.common.util.EList;

import edu.kit.ipd.descartes.perfdatarepo.Impact;
import edu.kit.ipd.descartes.perfdatarepo.PerformanceDataRepository;
import edu.kit.ipd.descartes.perfdatarepo.Result;

public class PerfDataRepoHelper {

	/**
	 * Queries for the latest impact. The latest impact is determined by the
	 * {@link Result} with the most recent timestamp. Currently it is the last one in
	 * the list.
	 */
	public static Impact getLatestImpact(PerformanceDataRepository perfDataRepo) {
		
		EList<Impact> impactHistory = perfDataRepo.getImpactHistory();
		Impact mostRecentImpact =  impactHistory.get(impactHistory.size() - 1);
				
		for (Impact currentImpact : impactHistory) {
			Result afterResult = currentImpact.getAfter();
			if (afterResult.getTimestamp().compareTo(mostRecentImpact.getAfter().getTimestamp()) > 0 )
				mostRecentImpact = currentImpact;
		}
		
		return mostRecentImpact;
	}
	

	/**
	 * Returns the {@link Impact} at position {@code position} in the
	 * impact list of the given {@link PerformanceDataRepository}
	 * 
	 * @param perfDataRepo {@link PerformanceDataRepository} containing all impacts
	 * @param position The position of the impact to return
	 * @return
	 */
	public static Impact getImpactAt(PerformanceDataRepository perfDataRepo, int position) {
		EList<Impact> impactHistory = perfDataRepo.getImpactHistory();
		if (position > impactHistory.size() - 1)
		    return null;
		return impactHistory.get(position);
	}
}
